
#ifndef VTKPVADAPTORSPAGOSA_EXPORT_H
#define VTKPVADAPTORSPAGOSA_EXPORT_H

#ifdef VTKPVADAPTORSPAGOSA_STATIC_DEFINE
#  define VTKPVADAPTORSPAGOSA_EXPORT
#  define VTKPVADAPTORSPAGOSA_NO_EXPORT
#else
#  ifndef VTKPVADAPTORSPAGOSA_EXPORT
#    ifdef AdaptorsPagosa_EXPORTS
        /* We are building this library */
#      define VTKPVADAPTORSPAGOSA_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define VTKPVADAPTORSPAGOSA_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef VTKPVADAPTORSPAGOSA_NO_EXPORT
#    define VTKPVADAPTORSPAGOSA_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef VTKPVADAPTORSPAGOSA_DEPRECATED
#  define VTKPVADAPTORSPAGOSA_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef VTKPVADAPTORSPAGOSA_DEPRECATED_EXPORT
#  define VTKPVADAPTORSPAGOSA_DEPRECATED_EXPORT VTKPVADAPTORSPAGOSA_EXPORT VTKPVADAPTORSPAGOSA_DEPRECATED
#endif

#ifndef VTKPVADAPTORSPAGOSA_DEPRECATED_NO_EXPORT
#  define VTKPVADAPTORSPAGOSA_DEPRECATED_NO_EXPORT VTKPVADAPTORSPAGOSA_NO_EXPORT VTKPVADAPTORSPAGOSA_DEPRECATED
#endif

#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef VTKPVADAPTORSPAGOSA_NO_DEPRECATED
#    define VTKPVADAPTORSPAGOSA_NO_DEPRECATED
#  endif
#endif

/* VTK-HeaderTest-Exclude: vtkPVAdaptorsPagosaModule.h */

/* Include ABI Namespace */
#include "vtkABINamespace.h"

#endif /* VTKPVADAPTORSPAGOSA_EXPORT_H */
